<?php

namespace Drupal\Tests\xp\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Defines an abstract test base for xp tests.
 */
abstract class XpBrowserTestBase extends BrowserTestBase {

  /**
   * Set default theme to stable.
   *
   * @var string
   */
  protected $defaultTheme = 'stable';

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = ['xp'];

  /**
   * Place breadcrumb page, tasks, and actions.
   */
  protected function placeBlocks() {
    $this->drupalPlaceBlock('system_breadcrumb_block');
    $this->drupalPlaceBlock('page_title_block');
    $this->drupalPlaceBlock('local_tasks_block');
    $this->drupalPlaceBlock('local_actions_block');
  }

  /**
   * Assert block content and paragraph types are installed.
   *
   * @param string $block_content_type
   *   Block content type.
   * @param string $paragraph_type
   *   Paragraph type.
   */
  protected function assertInstallBlockConfig($block_content_type, $paragraph_type) {
    $assert = $this->assertSession();
    $this->drupalGet('/admin/structure/block/block-content/manage/' . $block_content_type);
    $assert->statusCodeEquals(200);
    $this->drupalGet('/admin/structure/paragraphs_type/' . $paragraph_type);
    $assert->statusCodeEquals(200);
  }

  /**
   * Assert block content and paragraph types are uninstalled.
   *
   * @param string $block_content_type
   *   Block content type.
   * @param string $paragraph_type
   *   Paragraph type.
   */
  protected function assertUninstallBlockConfig($block_content_type, $paragraph_type) {
    $assert = $this->assertSession();
    $this->drupalGet('/admin/structure/block/block-content/manage/' . $block_content_type);
    $assert->statusCodeEquals(404);
    $this->drupalGet('/admin/structure/paragraphs_type/' . $paragraph_type);
    $assert->statusCodeEquals(404);
  }

}
